@@ -46,13 +46,13 @@ using namespace KCalCore;
 Compat *CompatFactory::createCompat(const QString &productId,
                                     const QString &implementationVersion)
 {
-    Compat *compat = 0;
+    Compat *compat = nullptr;
 
     int korg = productId.indexOf(QStringLiteral("KOrganizer"));
     int outl9 = productId.indexOf(QStringLiteral("Outlook 9.0"));
 
     if (korg >= 0) {
-        int versionStart = productId.indexOf(QStringLiteral(" "), korg);
+        int versionStart = productId.indexOf(QLatin1Char(' '), korg);
         if (versionStart >= 0) {
             int versionStop = productId.indexOf(QRegExp(QStringLiteral("[ /]")), versionStart + 1);
             if (versionStop >= 0) {
@@ -62,7 +62,7 @@ Compat *CompatFactory::createCompat(const QString &productId,
                 int versionNum = version.section(QLatin1Char('.'), 0, 0).toInt() * 10000 +
                                  version.section(QLatin1Char('.'), 1, 1).toInt() * 100 +
                                  version.section(QLatin1Char('.'), 2, 2).toInt();
-                int releaseStop = productId.indexOf(QStringLiteral("/"), versionStop);
+                int releaseStop = productId.indexOf(QLatin1Char('/'), versionStop);
                 QString release;
                 if (releaseStop > versionStop) {
                     release = productId.mid(versionStop + 1, releaseStop - versionStop - 1);
@@ -100,7 +100,7 @@ Compat *CompatFactory::createCompat(const QString &productId,
     return compat;
 }
 
-Compat::Compat() : d(0)
+Compat::Compat() : d(nullptr)
 {
 }
 
@@ -212,7 +212,7 @@ void CompatDecorator::setCreatedToDtStamp(const Incidence::Ptr &incidence,
     d->compat->setCreatedToDtStamp(incidence, dtstamp);
 }
 
-CompatPre35::CompatPre35() : d(0)
+CompatPre35::CompatPre35() : d(nullptr)
 {
 }
 
@@ -236,7 +236,7 @@ void CompatPre35::fixRecurrence(const Incidence::Ptr &incidence)
     Compat::fixRecurrence(incidence);
 }
 
-CompatPre34::CompatPre34() : d(0)
+CompatPre34::CompatPre34() : d(nullptr)
 {
 }
 
@@ -254,7 +254,7 @@ int CompatPre34::fixPriority(int priority)
     }
 }
 
-CompatPre32::CompatPre32() : d(0)
+CompatPre32::CompatPre32() : d(nullptr)
 {
 }
 
@@ -272,7 +272,7 @@ void CompatPre32::fixRecurrence(const Incidence::Ptr &incidence)
     CompatPre35::fixRecurrence(incidence);
 }
 
-CompatPre31::CompatPre31() : d(0)
+CompatPre31::CompatPre31() : d(nullptr)
 {
 }
 
@@ -290,7 +290,7 @@ void CompatPre31::fixRecurrence(const Incidence::Ptr &incidence)
     CompatPre32::fixRecurrence(incidence);
 
     Recurrence *recur = incidence->recurrence();
-    RecurrenceRule *r = 0;
+    RecurrenceRule *r = nullptr;
     if (recur) {
         r = recur->defaultRRule();
     }
@@ -352,7 +352,7 @@ void CompatPre31::fixRecurrence(const Incidence::Ptr &incidence)
     }
 }
 
-CompatOutlook9::CompatOutlook9() : d(0)
+CompatOutlook9::CompatOutlook9() : d(nullptr)
 {
 }
 
@@ -380,7 +380,7 @@ void CompatOutlook9::fixAlarms(const Incidence::Ptr &incidence)
     }
 }
 
-Compat32PrereleaseVersions::Compat32PrereleaseVersions() : d(0)
+Compat32PrereleaseVersions::Compat32PrereleaseVersions() : d(nullptr)
 {
 }
 
@@ -395,7 +395,7 @@ bool Compat32PrereleaseVersions::useTimeZoneShift() const
 
 CompatPre410::CompatPre410(Compat *decoratedCompat)
     : CompatDecorator(decoratedCompat)
-    , d(0)
+    , d(nullptr)
 {
 }
 
